==============================
Redis cache backend for Django
==============================

Full featured redis cache backend for Django.

.. image:: https://travis-ci.org/niwibe/django-redis.png?branch=master
    :target: https://travis-ci.org/niwibe/django-redis

.. image:: https://pypip.in/v/django-redis/badge.png
    :target: https://crate.io/packages/django-redis

.. image:: https://pypip.in/d/django-redis/badge.png
    :target: https://crate.io/packages/django-redis


Documentation
-------------

http://niwibe.github.io/django-redis/


How to install
--------------

Run ``python setup.py install`` to install,
or place ``redis_cache`` on your Python path.

You can also install it with: ``pip install django-redis``


.. image:: https://d2weczhvl823v0.cloudfront.net/niwibe/django-redis/trend.png
   :alt: Bitdeli badge
   :target: https://bitdeli.com/free

